@@ -3,7 +3,6 @@
 import logging
 import os
 import shutil
-import sys
 import tempfile
 import urllib
 import zc.recipe.egg
@@ -209,7 +208,12 @@ class Recipe(zc.recipe.egg.Eggs):
             if key in keys:
                 entries[packages[keys.index(key)]] = k
         for key in entries.keys():
-            src = os.path.join(entries[key], key.split('.')[0])
+            top_level = os.path.join(ws.by_key[key]._provider.egg_info,
+                                     'top_level.txt')
+            top = open(top_level, 'r')
+            top_dir = top.read()
+            src = os.path.join(entries[key], top_dir.strip())
+            top.close()
             dir = os.path.join(lib, os.path.basename(src))
             egg_info_src = os.path.join(ws.by_key[key]._provider.egg_info,
                                         'SOURCES.txt')
